@@ -3,52 +3,52 @@
 <context>
     <name>Aide</name>
     <message>
-        <location filename="../Ui_help.py" line="150"/>
+        <location filename="../Ui_help.py" line="149"/>
         <source>Aide</source>
         <translation>Ajuda</translation>
     </message>
     <message>
-        <location filename="../Ui_help.py" line="149"/>
+        <location filename="../Ui_help.py" line="148"/>
         <source>Mode d&apos;emploi</source>
         <translation>Ordens para uso</translation>
     </message>
     <message>
-        <location filename="../Ui_help.py" line="157"/>
+        <location filename="../Ui_help.py" line="156"/>
         <source>A propos</source>
         <translation>Sobre</translation>
     </message>
     <message>
-        <location filename="../Ui_help.py" line="152"/>
+        <location filename="../Ui_help.py" line="151"/>
         <source>ScolaSync, pour gerer les fichiers des baladeurs</source>
         <translation>ScolaSync, para a gestão de ficheiros dos leitores de MP3</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_help.py" line="153"/>
+        <location filename="../Ui_help.py" line="152"/>
         <source>Numero de version :</source>
         <translation>Número de versão :</translation>
     </message>
     <message>
-        <location filename="../Ui_help.py" line="154"/>
+        <location filename="../Ui_help.py" line="153"/>
         <source>Auteurs</source>
         <translation>Autores</translation>
     </message>
     <message>
-        <location filename="../Ui_help.py" line="155"/>
+        <location filename="../Ui_help.py" line="154"/>
         <source>Licence</source>
         <translation>Licença</translation>
     </message>
     <message>
-        <location filename="../Ui_help.py" line="156"/>
+        <location filename="../Ui_help.py" line="155"/>
         <source>Langues et traductions</source>
         <translation>Idiomas e traduções</translation>
     </message>
     <message>
-        <location filename="../Ui_help.py" line="158"/>
+        <location filename="../Ui_help.py" line="157"/>
         <source>Fermer</source>
         <translation>Fechar</translation>
     </message>
     <message>
-        <location filename="../Ui_help.py" line="151"/>
+        <location filename="../Ui_help.py" line="150"/>
         <source>Manuel</source>
         <translation type="unfinished"></translation>
     </message>
@@ -56,17 +56,17 @@
 <context>
     <name>Dialog</name>
     <message encoding="UTF-8">
-        <location filename="../Ui_chooseInSticks.py" line="138"/>
+        <location filename="../Ui_chooseInSticks.py" line="136"/>
         <source>Choix de fichiers à supprimer</source>
         <translation>Escolha dos ficheiros a suprimir</translation>
     </message>
     <message>
-        <location filename="../Ui_chooseInSticks.py" line="139"/>
+        <location filename="../Ui_chooseInSticks.py" line="137"/>
         <source>Zone de recherche</source>
         <translation>Zona de pesquisa</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_chooseInSticks.py" line="140"/>
+        <location filename="../Ui_chooseInSticks.py" line="138"/>
         <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
 &lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
 p, li { white-space: pre-wrap; }
@@ -81,37 +81,37 @@ p, li { white-space: pre-wrap; }(new line)
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;documentos de &lt;br /&gt;travail&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_chooseInSticks.py" line="146"/>
+        <location filename="../Ui_chooseInSticks.py" line="144"/>
         <source>Le répertoire des clés&lt;br&gt;où se trouvent les&lt;br&gt;documents de travail</source>
         <translation>A pasta das chaves&lt;br&gt;aonde se encontram&lt;br&gt;os documentos de trabalho</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_chooseInSticks.py" line="147"/>
+        <location filename="../Ui_chooseInSticks.py" line="145"/>
         <source>Le répertoire des clés où se trouvent les documents de travail</source>
         <translation>A pasta das chaves aonde se encontram os documentos de trabalho</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_chooseInSticks.py" line="148"/>
+        <location filename="../Ui_chooseInSticks.py" line="146"/>
         <source>Choix de clé modèle</source>
         <translation>Escolha da chave modelo</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_chooseInSticks.py" line="150"/>
+        <location filename="../Ui_chooseInSticks.py" line="148"/>
         <source>Choisir une des clés</source>
         <translation>Escolher uma das chaves</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_chooseInSticks.py" line="151"/>
+        <location filename="../Ui_chooseInSticks.py" line="149"/>
         <source>Liste de fichiers à traiter (jokers autorisés)</source>
         <translation>Lista de ficheiros a tratar (jokers autorizados)</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_chooseInSticks.py" line="153"/>
+        <location filename="../Ui_chooseInSticks.py" line="151"/>
         <source>Supprimer l&apos;item sélectionné</source>
         <translation>Suprimir o elemento selecionado</translation>
     </message>
     <message>
-        <location filename="../Ui_copyToDialog1.py" line="194"/>
+        <location filename="../Ui_copyToDialog1.py" line="192"/>
         <source>...</source>
         <translation>...</translation>
     </message>
@@ -126,22 +126,22 @@ p, li { white-space: pre-wrap; }(new line)
         <translation type="obsolete">Acrescentar um ficheiro ou um filtro</translation>
     </message>
     <message>
-        <location filename="../Ui_chooseInSticks.py" line="161"/>
+        <location filename="../Ui_chooseInSticks.py" line="159"/>
         <source>Rechercher (fichier) ...</source>
         <translation>Procurar (ficheiro) ...</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_chooseInSticks.py" line="164"/>
+        <location filename="../Ui_chooseInSticks.py" line="162"/>
         <source>Rechercher (répertoire) ...</source>
         <translation>Procurar (pasta) ...</translation>
     </message>
     <message>
-        <location filename="../Ui_preferences.py" line="90"/>
+        <location filename="../Ui_preferences.py" line="89"/>
         <source>Preferences de ScolaSync</source>
         <translation>Preferências de ScolaSync</translation>
     </message>
     <message>
-        <location filename="../Ui_preferences.py" line="91"/>
+        <location filename="../Ui_preferences.py" line="90"/>
         <source>Preferences</source>
         <translation>Preferências</translation>
     </message>
@@ -156,82 +156,82 @@ p, li { white-space: pre-wrap; }(new line)
         <translation type="obsolete">Utilizar casas a assinalar para designar os leitores</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_preferences.py" line="96"/>
+        <location filename="../Ui_preferences.py" line="95"/>
         <source>Répertoire pour les travaux :</source>
         <translation>Pasta para os trabalhos :</translation>
     </message>
     <message>
-        <location filename="../Ui_preferences.py" line="97"/>
+        <location filename="../Ui_preferences.py" line="96"/>
         <source>Travail</source>
         <translation>Trabalho</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_copyToDialog1.py" line="170"/>
+        <location filename="../Ui_copyToDialog1.py" line="168"/>
         <source>Choix des fichiers à copier</source>
         <translation>Escolha dos ficheiros a copiar</translation>
     </message>
     <message>
-        <location filename="../Ui_copyToDialog1.py" line="171"/>
+        <location filename="../Ui_copyToDialog1.py" line="169"/>
         <source>/</source>
         <translation>/</translation>
     </message>
     <message>
-        <location filename="../Ui_copyToDialog1.py" line="172"/>
+        <location filename="../Ui_copyToDialog1.py" line="170"/>
         <source>Ordinateur</source>
         <translation>Computador</translation>
     </message>
     <message>
-        <location filename="../Ui_copyToDialog1.py" line="174"/>
+        <location filename="../Ui_copyToDialog1.py" line="172"/>
         <source>Disque dur</source>
         <translation>Disco duro</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_copyToDialog1.py" line="176"/>
+        <location filename="../Ui_copyToDialog1.py" line="174"/>
         <source>Répertoire de destination des baladeurs</source>
         <translation>Pasta de destinação dos leitores</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_copyToDialog1.py" line="178"/>
+        <location filename="../Ui_copyToDialog1.py" line="176"/>
         <source>Répertoire de destination sur les baladeurs,&lt;br&gt;peut être modifié dans les préférences</source>
         <translation>Pasta de destinação nos leitores,&lt;br&gt;pode ser modificada nas preferênçias</translation>
     </message>
     <message>
-        <location filename="../Ui_copyToDialog1.py" line="180"/>
+        <location filename="../Ui_copyToDialog1.py" line="178"/>
         <source>Baladeur</source>
         <translation>Leitor</translation>
     </message>
     <message>
-        <location filename="../Ui_copyToDialog1.py" line="183"/>
+        <location filename="../Ui_copyToDialog1.py" line="181"/>
         <source>Disque flash</source>
         <translation>Disco flash</translation>
     </message>
     <message>
-        <location filename="../Ui_copyToDialog1.py" line="186"/>
+        <location filename="../Ui_copyToDialog1.py" line="184"/>
         <source>Cle USB</source>
         <translation>Chave USB</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_copyToDialog1.py" line="188"/>
+        <location filename="../Ui_copyToDialog1.py" line="186"/>
         <source>Taille totale :</source>
         <translation>Tamanho total :</translation>
     </message>
     <message>
-        <location filename="../Ui_copyToDialog1.py" line="190"/>
+        <location filename="../Ui_copyToDialog1.py" line="188"/>
         <source>Ajouter a la liste</source>
         <translation>Acrenscentar à lista</translation>
     </message>
     <message>
-        <location filename="../Ui_copyToDialog1.py" line="193"/>
+        <location filename="../Ui_copyToDialog1.py" line="191"/>
         <source>Retirer de la liste</source>
         <translation>Tirar da lista</translation>
     </message>
     <message>
-        <location filename="../Ui_copyToDialog1.py" line="195"/>
+        <location filename="../Ui_copyToDialog1.py" line="193"/>
         <source>Abandonner</source>
         <translation>Abandonar</translation>
     </message>
     <message>
-        <location filename="../Ui_copyToDialog1.py" line="196"/>
+        <location filename="../Ui_copyToDialog1.py" line="194"/>
         <source>Continuer ...</source>
         <translation>Continuar...</translation>
     </message>
@@ -301,12 +301,12 @@ p, li { white-space: pre-wrap; }(new line)
         <translation>Escolha um destino para a cópia dos ficheiros</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="" line="1768190543"/>
+        <location filename="." line="1768190543"/>
         <source>Liste de périphériques modifiée pour Scolasync</source>
         <translation type="obsolete">Lista de periphéricos modificada para o Scolasync</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="" line="1768190543"/>
+        <location filename="." line="1768190543"/>
         <source>Une clé USB ou un baladeur numérique au moins a change de statut. Vérifiez éventuellement la liste des périphériques de Scolasync</source>
         <translation type="obsolete">Pelo menos uma chave USB ou um leitor numérico mudou de estatuto. Verifique eventualmente a lista dos periphéricos de Scolasync</translation>
     </message>
@@ -346,22 +346,22 @@ p, li { white-space: pre-wrap; }(new line)
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_preferences.py" line="98"/>
+        <location filename="../Ui_preferences.py" line="97"/>
         <source>Fichier spécial pour le manuel :</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_preferences.py" line="99"/>
+        <location filename="../Ui_preferences.py" line="98"/>
         <source>/usr/share/scolasync/help/manualPage_fr_FR.html</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_chooseInSticks.py" line="159"/>
+        <location filename="../Ui_chooseInSticks.py" line="157"/>
         <source>Ligne d&apos;édition du nom d&apos;un fichier ou d&apos;un répertoire.&lt;br&gt;Jokers autorisés</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_chooseInSticks.py" line="156"/>
+        <location filename="../Ui_chooseInSticks.py" line="154"/>
         <source>Ajouter un fichier ou un filtre défini dans la ligne d&apos;édition</source>
         <translation type="unfinished"></translation>
     </message>
@@ -371,112 +371,112 @@ p, li { white-space: pre-wrap; }(new line)
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_preferences.py" line="94"/>
+        <location filename="../Ui_preferences.py" line="93"/>
         <source>Efface les fichiers et les répertoires après copie</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_preferences.py" line="92"/>
+        <location filename="../Ui_preferences.py" line="91"/>
         <source>Si la case est cochée,&lt;br&gt;les données sont transférées sur le disque dur&lt;br&gt;puis effacée des baladeurs.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_preferences.py" line="93"/>
+        <location filename="../Ui_preferences.py" line="92"/>
         <source>Si la case est cochée, les données sont transférées sur le disque dur puis effacée des baladeurs.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_choixEleves.py" line="113"/>
+        <location filename="../Ui_choixEleves.py" line="111"/>
         <source>Choix d&apos;un groupe d&apos;élèves</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_choixEleves.py" line="116"/>
+        <location filename="../Ui_choixEleves.py" line="114"/>
         <source>Actions</source>
         <translation type="unfinished">Ações</translation>
     </message>
     <message>
-        <location filename="../Ui_choixEleves.py" line="117"/>
+        <location filename="../Ui_choixEleves.py" line="115"/>
         <source>Replier toutes les classes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_choixEleves.py" line="118"/>
+        <location filename="../Ui_choixEleves.py" line="116"/>
         <source>Tout replier</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_choixEleves.py" line="119"/>
+        <location filename="../Ui_choixEleves.py" line="117"/>
         <source>Cocher tous les élèves visibles</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_choixEleves.py" line="120"/>
+        <location filename="../Ui_choixEleves.py" line="118"/>
         <source>Cocher</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_choixEleves.py" line="121"/>
+        <location filename="../Ui_choixEleves.py" line="119"/>
         <source>Décocher tous les élèves, visibles ou non</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_choixEleves.py" line="122"/>
+        <location filename="../Ui_choixEleves.py" line="120"/>
         <source>Décocher</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_choixEleves.py" line="124"/>
+        <location filename="../Ui_choixEleves.py" line="122"/>
         <source>Ajout à la liste</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_choixEleves.py" line="126"/>
+        <location filename="../Ui_choixEleves.py" line="124"/>
         <source>Suppr. de la liste</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_choixEleves.py" line="131"/>
+        <location filename="../Ui_choixEleves.py" line="129"/>
         <source>Valider</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_choixEleves.py" line="128"/>
+        <location filename="../Ui_choixEleves.py" line="126"/>
         <source>N° à partir de</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_choixEleves.py" line="127"/>
+        <location filename="../Ui_choixEleves.py" line="125"/>
         <source>Quand la case est cochée, un numéro sera ajouté comme préfixe aux noms</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_choixEleves.py" line="129"/>
+        <location filename="../Ui_choixEleves.py" line="127"/>
         <source>La numérotation commence à cette valeur</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_choixEleves.py" line="123"/>
+        <location filename="../Ui_choixEleves.py" line="121"/>
         <source>Ajouter les noms cochés de l&apos;arbre dans la liste à droite</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_choixEleves.py" line="125"/>
+        <location filename="../Ui_choixEleves.py" line="123"/>
         <source>Supprimer de la liste les noms en surbrillance</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_choixEleves.py" line="130"/>
+        <location filename="../Ui_choixEleves.py" line="128"/>
         <source>Accepter la liste actuelle et fermer ce dialogue</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_choixEleves.py" line="132"/>
+        <location filename="../Ui_choixEleves.py" line="130"/>
         <source>Supprimer tous les noms de la liste et fermer ce dialogue</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_choixEleves.py" line="133"/>
+        <location filename="../Ui_choixEleves.py" line="131"/>
         <source>Remettre à zéro</source>
         <translation type="unfinished"></translation>
     </message>
@@ -491,67 +491,67 @@ p, li { white-space: pre-wrap; }(new line)
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_choixEleves.py" line="114"/>
+        <location filename="../Ui_choixEleves.py" line="112"/>
         <source>Liste d&apos;élèves</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_choixEleves.py" line="115"/>
+        <location filename="../Ui_choixEleves.py" line="113"/>
         <source>Ouvrir un fichier ...</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_preferences.py" line="95"/>
+        <location filename="../Ui_preferences.py" line="94"/>
         <source>Fichier des élèves :</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_nameAdrive.py" line="68"/>
+        <location filename="../Ui_nameAdrive.py" line="67"/>
         <source>Nommer le baladeur nouvellement connecté</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_nameAdrive.py" line="69"/>
+        <location filename="../Ui_nameAdrive.py" line="68"/>
         <source>Changez le choix parmi cette liste si une autre ligne convient mieux</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_nameAdrive.py" line="71"/>
+        <location filename="../Ui_nameAdrive.py" line="70"/>
         <source>nom actuel du baladeur</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_nameAdrive.py" line="72"/>
+        <location filename="../Ui_nameAdrive.py" line="71"/>
         <source>C&apos;est le nom connu par votre ordinateur, s&apos;il a déjà été défini dans le passé</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_nameAdrive.py" line="73"/>
+        <location filename="../Ui_nameAdrive.py" line="72"/>
         <source>nom proposé</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_nameAdrive.py" line="74"/>
+        <location filename="../Ui_nameAdrive.py" line="73"/>
         <source>Le nouveau nom proposé peut venir de la liste à gauche ou être modifié à la main</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_nameAdrive.py" line="75"/>
+        <location filename="../Ui_nameAdrive.py" line="74"/>
         <source>Renommer le baladeur</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_nameAdrive.py" line="76"/>
+        <location filename="../Ui_nameAdrive.py" line="75"/>
         <source>Choisir comme nouveau nom</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_nameAdrive.py" line="77"/>
+        <location filename="../Ui_nameAdrive.py" line="76"/>
         <source>Fermer le dialogue sans rien faire</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_nameAdrive.py" line="78"/>
+        <location filename="../Ui_nameAdrive.py" line="77"/>
         <source>Échappement</source>
         <translation type="unfinished"></translation>
     </message>
@@ -667,12 +667,12 @@ p, li { white-space: pre-wrap; }(new line)
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../Ui_mainWindow.py" line="152"/>
+        <location filename="../Ui_mainWindow.py" line="151"/>
         <source>ScolaSync</source>
         <translation>Scolasync</translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="153"/>
+        <location filename="../Ui_mainWindow.py" line="152"/>
         <source>Actions</source>
         <translation>Ações</translation>
     </message>
@@ -682,7 +682,7 @@ p, li { white-space: pre-wrap; }(new line)
         <translation type="obsolete">Copiar a partir dos leitores</translation>
     </message>
     <message>
-        <location filename="../Ui_diskFull.py" line="53"/>
+        <location filename="../Ui_diskFull.py" line="52"/>
         <source>...</source>
         <translation>... </translation>
     </message>
@@ -707,37 +707,37 @@ p, li { white-space: pre-wrap; }(new line)
         <translation type="obsolete">Preferéncias</translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="179"/>
+        <location filename="../Ui_mainWindow.py" line="178"/>
         <source>Aide</source>
         <translation>Ajuda</translation>
     </message>
     <message>
-        <location filename="../Ui_diskFull.py" line="52"/>
+        <location filename="../Ui_diskFull.py" line="51"/>
         <source>Disk size</source>
         <translation>Tamanho do disco</translation>
     </message>
     <message>
-        <location filename="../Ui_diskFull.py" line="54"/>
+        <location filename="../Ui_diskFull.py" line="53"/>
         <source>total size</source>
         <translation>Tamanho total</translation>
     </message>
     <message>
-        <location filename="../Ui_diskFull.py" line="55"/>
+        <location filename="../Ui_diskFull.py" line="54"/>
         <source>Used</source>
         <translation>Utilizado</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_mainWindow.py" line="173"/>
+        <location filename="../Ui_mainWindow.py" line="172"/>
         <source>Force à recompter les baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_mainWindow.py" line="171"/>
+        <location filename="../Ui_mainWindow.py" line="170"/>
         <source>Affiche le nombre de baladeurs connectés</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_mainWindow.py" line="176"/>
+        <location filename="../Ui_mainWindow.py" line="175"/>
         <source>Préférences</source>
         <translation type="unfinished"></translation>
     </message>
@@ -752,22 +752,22 @@ p, li { white-space: pre-wrap; }(new line)
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_mainWindow.py" line="164"/>
+        <location filename="../Ui_mainWindow.py" line="163"/>
         <source>Éjecter les baladeurs sélectionnés</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_mainWindow.py" line="155"/>
+        <location filename="../Ui_mainWindow.py" line="154"/>
         <source>Copier depuis les baladeurs sélectionnés</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_mainWindow.py" line="158"/>
+        <location filename="../Ui_mainWindow.py" line="157"/>
         <source>Copier vers les baladeurs sélectionnés</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_mainWindow.py" line="161"/>
+        <location filename="../Ui_mainWindow.py" line="160"/>
         <source>Effacer des fichiers ou des dossiers dans les baladeurs sélectionnés</source>
         <translation type="unfinished"></translation>
     </message>
@@ -795,63 +795,53 @@ p, li { white-space: pre-wrap; }(new line)
 <context>
     <name>checkBoxDialog</name>
     <message encoding="UTF-8">
-        <location filename="../Ui_checkBoxDialog.py" line="51"/>
+        <location filename="../Ui_checkBoxDialog.py" line="50"/>
         <source>Gestion des cases à cocher</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_checkBoxDialog.py" line="53"/>
+        <location filename="../Ui_checkBoxDialog.py" line="52"/>
         <source>Cocher tous les baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_checkBoxDialog.py" line="54"/>
+        <location filename="../Ui_checkBoxDialog.py" line="53"/>
         <source>Tout cocher</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_checkBoxDialog.py" line="56"/>
+        <location filename="../Ui_checkBoxDialog.py" line="55"/>
         <source>Inverser le choix de baladeurs&lt;br&gt;Les baladeurs cochés seront décochés, et inversement</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_checkBoxDialog.py" line="57"/>
+        <location filename="../Ui_checkBoxDialog.py" line="56"/>
         <source>Inverser le choix</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_checkBoxDialog.py" line="59"/>
+        <location filename="../Ui_checkBoxDialog.py" line="58"/>
         <source>Désélectionner les baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_checkBoxDialog.py" line="60"/>
+        <location filename="../Ui_checkBoxDialog.py" line="59"/>
         <source>Ne rien cocher</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_checkBoxDialog.py" line="62"/>
+        <location filename="../Ui_checkBoxDialog.py" line="61"/>
         <source>Ne rien faire</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_checkBoxDialog.py" line="63"/>
+        <location filename="../Ui_checkBoxDialog.py" line="62"/>
         <source>Échappement</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context encoding="UTF-8">
     <name>diskFull</name>
-    <message encoding="UTF-8">
-        <location filename="../diskFull.py" line="49"/>
-        <source>Place totale : %1 kilo-octets</source>
-        <translation type="obsolete">Lugar total : %1 kilobytes</translation>
-    </message>
-    <message encoding="UTF-8">
-        <location filename="../diskFull.py" line="50"/>
-        <source>Place utilisée : %1 kilo-octets</source>
-        <translation type="obsolete">Lugar utilizado : %1 kilobytes</translation>
-    </message>
     <message encoding="UTF-8">
         <location filename="../diskFull.py" line="49"/>
         <source>Place totale : {size} kilo-octets</source>
